#
# spec file for package iotop-c
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iotop-c
Version:        1.27
Release:        1.2
Summary:        Simple top-like I/O monitor (implemented in C)
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://github.com/Tomas-M/iotop
Source:         %{name}-%{version}.tar.xz
Conflicts:      iotop
BuildRequires:  gcc
BuildRequires:  pkgconfig(ncurses)

%description
iotop-c does for I/O usage what top(1) does for CPU usage. It watches I/O usage
information output by the Linux kernel and displays a table of current I/O usage
by processes on the system. It is handy for answering the question "Why is the
disk churning so much?".

iotop-c requires a Linux kernel built with the CONFIG_TASKSTATS,
CONFIG_TASK_DELAY_ACCT, CONFIG_TASK_IO_ACCOUNTING and CONFIG_VM_EVENT_COUNTERS
config options on.

iotop-c is an alternative re-implementation of iotop in C, optimized for
performance. Normally a monitoring tool intended to be used on a system under
heavy stress should use the least additional resources as possible.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%make_build

%install
V=1 STRIP=: %make_install

%files
%{_sbindir}/*
%{_mandir}/man8/*
%license LICENSE
%doc README.md

%changelog
* Mon Jan 13 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.27:
  * src/iotop: correct pg_cb signature #64
* Sat Feb  3 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.26:
  * Add clock in upper right corner
* Sat Oct 14 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.25:
  * Fix bug when iotop busy loops after pressing ESC key
  * Change the condition of displaying processes in only mode
* Sun Oct  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.24:
  * Fix a bug with graphs in ASCII mode
  * Show the status of the configuration in the help window
  * Support ancient compilers #52
* Tue Jan 24 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.23:
  * Changes by @bbonev in #43
  * Fix some issues reported by lintian by @debian-janitor in #42
  * Revert syscall count stuff by @bbonev in #44
  * fix empty archlinux package by @bokunodev in #46
* Mon Oct 24 2022 mvetter@suse.com
- Update to version 1.22:
  * view_curses: do not force black background #29
  * fixed scroller logic #30
  * fixed corner case of full scroller #32
  * Update README.md #35
  * Add regex search
  * Better checking and error handling in netlink code
  * More graceful signal handling
  * Fix bug with a missing check if a process exited
  * New option to hide exited processes
  * Add color to %% values and option to disable color at all
  * Implement the suggestion from https://no-color.org
  * Fix bug with cursor displayed in unusual places
* Wed Feb  2 2022 jonathan@jontech.app
- Update to version 1.21:
  * Better support for disabled task_delayacct sysctl
  * Add history and graph for all data
  * Restore simple inline help
- Fix debuginfo generation
* Mon Dec 13 2021 Jonathan Papineau <jonathan@jontech.app>
- Initial packaging of iotop-c 1.20
